@@ -70,18 +70,18 @@ import org.glassfish.grizzly.http.HttpContent;
 import org.glassfish.grizzly.http.HttpRequestPacket;
 import org.glassfish.grizzly.http.HttpResponsePacket;
 import org.glassfish.grizzly.http.Protocol;
+import org.glassfish.grizzly.http.util.HttpStatus;
 import org.glassfish.grizzly.http.util.Parameters;
 import org.glassfish.grizzly.websockets.DataFrame;
 import org.glassfish.grizzly.websockets.HandshakeException;
 import org.glassfish.grizzly.websockets.ProtocolHandler;
 import org.glassfish.grizzly.websockets.WebSocket;
 import org.glassfish.grizzly.websockets.WebSocketApplication;
-import org.glassfish.grizzly.websockets.WebSocketListener;
 import org.glassfish.grizzly.websockets.WebSocketException;
+import org.glassfish.grizzly.websockets.WebSocketListener;
 import org.slf4j.Logger;
 import com.google.common.cache.Cache;
 import com.google.common.cache.CacheBuilder;
-import com.google.common.collect.ImmutableSet;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.cascade.ComposedConfigProperty;
 import com.openexchange.config.cascade.ConfigView;
@@ -216,7 +216,11 @@ public abstract class AbstractGrizzlyWebSocketApplication<S extends SessionBound
             }
             i.remove();
         }
-        for (WebSocket socket : ImmutableSet.<WebSocket> copyOf(getWebSockets())) {
+        List<WebSocket> webSocketsToRemove = new LinkedList<>();
+        for (Iterator<WebSocket> it = getWebSockets().iterator(); it.hasNext();) {
+            webSocketsToRemove.add(it.next());
+        }
+        for (WebSocket socket : webSocketsToRemove) {
             remove(socket);
             socket.close();
         }
@@ -408,23 +412,31 @@ public abstract class AbstractGrizzlyWebSocketApplication<S extends SessionBound
     }
 
     /**
-     * Handles the specified <code>HandshakeException</code>.
+     * Handles the specified <code>HandshakeException</code>, which describes the error, occurred during the WebSocket handshake phase
      *
      * @param e The exception to handle
      * @param handler The associated protocol handler
      * @param requestPacket The request package
      */
     protected void handleHandshakeException(HandshakeException e, ProtocolHandler handler, HttpRequestPacket requestPacket) {
+        LOGGER.debug("Failed to establish Web Socket connection", e);
         FilterChainContext ctx = handler.getFilterChainContext();
         HttpResponsePacket response = requestPacket.getResponse();
         response.setProtocol(Protocol.HTTP_1_1);
-        response.setStatus(401);
-        response.setReasonPhrase("Authorization Required");
+
+        HttpStatus httpStatus = HttpStatus.getHttpStatus(e.getCode());
+        if (null == httpStatus) {
+            // No such HTTP status known...
+            httpStatus = HttpStatus.BAD_REQUEST_400;
+        }
+        response.setStatus(httpStatus.getStatusCode());
+        response.setReasonPhrase(httpStatus.getReasonPhrase());
+
         ctx.write(HttpContent.builder(response).build());
     }
 
     /**
-     * Handles the specified <code>HandshakeException</code>.
+     * Handles the specified <code>WebSocketException</code>.
      *
      * @param e The exception to handle
      * @param handler The associated protocol handler
