@@ -73,13 +73,13 @@ import com.hazelcast.core.Cluster;
 import com.hazelcast.core.HazelcastException;
 import com.hazelcast.core.HazelcastInstance;
 import com.hazelcast.core.HazelcastInstanceNotActiveException;
-import com.hazelcast.core.Hazelcasts;
 import com.hazelcast.core.IExecutorService;
 import com.hazelcast.core.Member;
 import com.hazelcast.core.MultiMap;
 import com.hazelcast.nio.Address;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
+import com.openexchange.hazelcast.Hazelcasts;
 import com.openexchange.java.UnsynchronizedBufferingQueue;
 import com.openexchange.session.UserAndContext;
 import com.openexchange.timer.ScheduledTimerTask;
